@@ -756,11 +756,6 @@ generate_key(ec) ->
 generate_key(rsa) ->
     public_key:generate_key({rsa, 2048, 65537}).
 
-%% OTP-28.0-rc4 in commit b230e26c4f6530563919b19e76f2d2e96e436048
-%% removed in the file lib/public_key/asn1/PKCS-10.asn1
-%% several definitions. Let's add manually the macro here:
--define('p1_acme-pkcs-9-at-extensionRequest', {1,2,840,113549,1,9,14}).
-
 -spec generate_csr([domain(), ...], priv_key()) -> #'CertificationRequest'{}.
 generate_csr([_|_] = Domains, PrivKey) ->
     SignAlgoOID = signature_algorithm(PrivKey),
@@ -774,7 +769,7 @@ generate_csr([_|_] = Domains, PrivKey) ->
 			  critical = false,
 			  extnValue = DerSAN}],
     DerExtnReq = public_key:der_encode('ExtensionRequest', Extns),
-    Attribute = #'AttributePKCS-10'{type = ?'p1_acme-pkcs-9-at-extensionRequest',
+    Attribute = #'Attribute'{type = ?'pkcs-9-at-extensionRequest',
 				    values = [{asn1_OPENTYPE, DerExtnReq}]},
     SubjPKInfo = #'CertificationRequestInfo_subjectPKInfo'{
 		    subjectPublicKey = subject_pubkey(PubKey),
@@ -905,7 +900,7 @@ find_issuer_cert(_Cert, []) ->
 jose_json(State, JSON, URL) when is_map(JSON) ->
     jose_json(State, encode_json(JSON), URL);
 jose_json(#state{account = {Key, AccURL}, nonce = Nonce} = State, Data, URL) ->
-    PrivKey = jose_jwk:from_key(Key),
+    PrivKey = jose_jwk:from_key(convert_key_version_jose(Key)),
     PubKey = jose_jwk:to_public(PrivKey),
     AlgMap = case jose_jwk:signer(PrivKey) of
 		 M when is_record(Key, 'RSAPrivateKey') ->
@@ -930,7 +925,7 @@ jose_json(#state{account = {Key, AccURL}, nonce = Nonce} = State, Data, URL) ->
 
 -spec auth_key(state(), binary()) -> binary().
 auth_key(#state{account = {PrivKey, _}}, Token) ->
-    Thumbprint = jose_jwk:thumbprint(jose_jwk:from_key(PrivKey)),
+    Thumbprint = jose_jwk:thumbprint(jose_jwk:from_key(convert_key_version_jose(PrivKey))),
     <<Token/binary, $., Thumbprint/binary>>.
 
 -spec encode_json(map()) -> binary().
@@ -949,6 +944,12 @@ json_decode_maps(Bin) ->
     json:decode(Bin).
 -endif.
 
+%% Erlang/OTP 28 generates this, but Jose 1.11.10 doesn't support it
+convert_key_version_jose(#'ECPrivateKey'{version = ecPrivkeyVer1} = Key) ->
+    Key#'ECPrivateKey'{version = 1};
+convert_key_version_jose(Key) ->
+    Key.
+
 %%%===================================================================
 %%% Misc
 %%%===================================================================
